@@ -531,6 +531,23 @@ bool g_fRecordTest = false;
 // ------ MAIN ------
 int main(int argc, char *argv[])
 {
+
+	system("/usr/bin/gconftool-2 -g /apps/osso/inputmethod/int_kb_layout > /home/user/int_kb_layout");
+
+ 	FILE *archivo;
+	char caracteres[100];
+	int c;
+ 	archivo = fopen("/home/user/int_kb_layout","r");
+	do { c = fscanf(archivo, "%s", caracteres); }
+    while (c != EOF); 
+
+ 	//while (feof(archivo) == 0) { fgets(caracteres,100,archivo); }
+
+	printf("\nEl contenido del archivo de prueba es -%s-\n\n",caracteres);
+	fclose(archivo);
+	if (caracteres!="us") system("/usr/bin/gconftool-2 -s /apps/osso/inputmethod/int_kb_layout us -t string");
+
+
 	printf("-------------------------------------------------------------------------------\n");
 	printf(" %s %s\n", TITLESTRING, VERSIONNUMBER);
 	printf("-------------------------------------------------------------------------------\n");
@@ -825,13 +842,8 @@ int main(int argc, char *argv[])
 	fp = fopen("D:\\options.bin", "rb");
 #else
 #ifdef PREFIXPATH
-	char * folder=getenv("HOME");
-#ifdef __MACOSX__
-	std::string optionsbin=std::string(folder)+
-		std::string("/Library/Preferences/smw.options.bin");
-#else
+    char * folder=getenv("HOME");
     std::string optionsbin=std::string(folder)+std::string("/.smw.options.bin");
-#endif
     fp = fopen(optionsbin.c_str(), "rb");
 #else
 	fp = fopen("options.bin", "rb");
@@ -1036,6 +1048,17 @@ int main(int argc, char *argv[])
 	gfx_close();
 	//net_close();
 
+
+ 	FILE *archivo2;
+	char caracteres2[100];
+	int c2;
+ 	archivo2 = fopen("/home/user/int_kb_layout","r");
+	do { c2 = fscanf(archivo2, "%s", caracteres2); }
+	while (c2 != EOF); 
+	fclose(archivo2);
+	if (caracteres2!="us") system("/usr/bin/gconftool-2 -s /apps/osso/inputmethod/int_kb_layout $(cat /home/user/int_kb_layout) -t string");
+
+
 	//netServer.cleanup();
 	//netClient.cleanup();
 
@@ -1429,7 +1452,7 @@ void RunGame()
 							game_values.gamestate = GS_QUIT;
 							return;
 						}
-						else if(event.key.keysym.sym == SDLK_RETURN)
+						else if(event.key.keysym.sym == SDLK_a)
 						{
 							game_values.fullscreen = !game_values.fullscreen;
 							gfx_setresolution(640, 480, game_values.fullscreen);
