@@ -266,7 +266,7 @@ bool LoadGameGraphics()
 
 #ifdef _DEBUG
 	_load_gfxck(spr_tanooki, convertPath("gfx/packs/powerups/tanooki.png", graphicspack));
-	_load_gfxck(spr_statue, convertPath("gfx/packs/projectiles/statue.png", graphicspack));
+	_load_gfxck(spr_statue, convertPath("gfx/packs/powerups/statue.png", graphicspack));
 #endif
 	_load_gfxck(spr_starpowerup, convertPath("gfx/packs/powerups/starpowerup.png", graphicspack));
 	_load_gfxck(spr_1uppowerup, convertPath("gfx/packs/powerups/1uppowerup.png", graphicspack));
@@ -532,21 +532,21 @@ bool LoadAndSplashScreen()
 	"matsche", "aeroflare", "Tymoe", "David Olofson", "scoti",
 	"affeOHNEwaffe", "mademan", "mario piuk", "yvoo", "DNightmare", 
 	"Armen", "vvill", "zio tiok", "Donny Viszneki","alex-rus07", "JacobTheHero",
-	"Stephan Peijnik", "ventuz", "Stefan Schury", "riahc3",
+	"Stephan Peijnik", "ventuz", "Stefan Schury", "DrJonez", "riahc3",
 	"jinkies.uk", "devguy", "Alexis Morrissette", "Bidbood", "Quinn Storm",
 	"Flexserve", "Xijar", "j rok", "nitsuja", "4matsy", "leftyfb",
 	"Brian Porter", "Brandon Stansbury", "Brian Smith", "Caesar Cypher",
 	"Chris Schager", "Alex Arnot", "Jason Lumbert", "Kevin King",
-	"Fernando Marquez", "DrJones", "SleepyP", "UltimateNinja9",
+	"Fernando Marquez", "DrJones", "SleepyP", "Jared", "UltimateNinja9",
 	"Alex Brown", "GKi", "mpinger", "neonater", "NMcCoy", "Rogultgot", "Arima",
 	"Toadeeboy", "Crapcom", "Tonberry2k", "Jum2004", "Bacon", "Tetra Vega",
 	"Young Link", "Blordow", "Gozinzolo", "Ragey", "SaturnEchidna", "Link901",
 	"Techokami", "dolorous", "SMW Fan", "Timonator", "YoshiMonarch7", "Tiptup300",
-	"Dude", "Justinio", "Matthew Callis", "VenomousNinja",
+	"Dude", "Sgraff87", "Justinio", "Matthew Callis", "VenomousNinja",
 	"Discrosh", "Ikill4you", "Helix Snake", "tubesteak", "wasabimario", "Lee",
 	"Pikawil", "Marioman64", "Peardian", "Bob Ippolito", "Viper Snake", "neavea",
 	"Mr.Bob-omb", "milua", "bobmanperson", "DrTek", "somestrangeflea", "nes6502",
-	"XPort", "Naphistim"};
+	"XPort"};
 
 #define NUM_CONTRIBUTORS ((int)(sizeof(contributors)/sizeof(char*)))
 
@@ -597,7 +597,7 @@ bool LoadAndSplashScreen()
 				{
 					switch(event.key.keysym.sym)
 					{
-						case SDLK_RETURN:
+						case SDLK_SPACE:
 							if(event.key.keysym.mod & (KMOD_LALT | KMOD_RALT))
 							{
 #ifndef _XBOX
